@@ -10,6 +10,9 @@ equals6 <- function(...)
 
 context("GeoSSE")
 
+test_that("geosse", {
+
+if (FALSE) {
 tree <- read.tree(text="((((0:0.461876,(1:0.307717,(2:0.231825,3:0.231825):0.075892):0.154159):0.425922,((4:0.244819,5:0.244819):0.004749,6:0.249568):0.638231):0.142051,7:1.029850):0.038423,(((8:0.510933,(9:0.427929,(10:0.119778,11:0.119778):0.308151):0.083004):0.007428,(12:0.488316,13:0.488316):0.030044):0.100160,14:0.618521):0.449752);")
 states <- c(0, 1, 0, 2, 1, 1, 1, 0, 1, 0, 0, 1, 0, 1, 0)
 names(states) <- as.character(seq(Ntip(tree))-1)
@@ -133,3 +136,5 @@ phy2 <- tree.classe(pars.c, max.t=5)
 lnL.c <- make.classe(phy2, phy2$tip.state, 3)
 lnL.g <- make.geosse(phy2, phy2$tip.state-1)
 expect_that(lnL.c(pars.c), equals(lnL.g(pars.g)))
+}
+})
